@@ -42,39 +42,41 @@
 #include "setup.h"
 #include "thread_utils.h"
 
+GnomeUIInfo *toolbar;
+GnomeUIInfo general_toolbar[] = {
+/*00*/ GNOMEUIINFO_SEPARATOR,
+/*01*/ GNOMEUIINFO_ITEM_STOCK (N_("New"), N_("New catalog"),
+			       cb_new_file, GNOME_STOCK_PIXMAP_NEW),
+/*02*/ GNOMEUIINFO_ITEM_STOCK (N_("Open"), N_("Open catalog"),
+			       cb_open_cat, GNOME_STOCK_PIXMAP_OPEN),
+/*03*/ GNOMEUIINFO_ITEM_STOCK (N_("Save"), N_("Save catalog"),
+			       cb_fast_save, GNOME_STOCK_PIXMAP_SAVE),
+/*04*/ GNOMEUIINFO_ITEM_STOCK (N_("Save as..."), N_("Save catalog as..."),
+			       cb_save_cat, GNOME_STOCK_PIXMAP_SAVE_AS),
+/*05*/ GNOMEUIINFO_ITEM_STOCK (N_("Edit categories"),
+			       N_("Edit categories"),
+			       cb_edit_categories,
+			       GNOME_STOCK_PIXMAP_PROPERTIES),
+/*06*/ GNOMEUIINFO_ITEM_STOCK (N_("Preferences"), N_("Preferences"),
+			       cb_run_setup, GNOME_STOCK_PIXMAP_PREFERENCES),
+/*07*/ GNOMEUIINFO_ITEM_STOCK (N_("Find file"), N_("Find file"),
+			       cb_create_search_dialog,
+			       GNOME_STOCK_PIXMAP_SEARCH),
+/*08*/ GNOMEUIINFO_ITEM_NONE (N_("Create Report"), N_("Create Report"),
+			      cb_open_report_dialog),
+/*09*/ GNOMEUIINFO_ITEM_STOCK (N_("Add CD"), N_("Add CD"),
+			       cb_fast_add_disk, GNOME_STOCK_PIXMAP_CDROM),
+/*10*/ GNOMEUIINFO_ITEM_STOCK (N_("Add dir"), N_("Add dir"),
+			       cb_show_select_dir_win,
+			       GNOME_STOCK_PIXMAP_CDROM),
+/*11*/ GNOMEUIINFO_ITEM_STOCK (N_("Exit"), N_("Quit Gtktalog"),
+			       cb_quit_prog, GNOME_STOCK_PIXMAP_EXIT),
+/*12*/ GNOMEUIINFO_END
+};
+
 void
 enable_gnome_button_bar (GtkWidget * window, gpointer data)
 {
-  GnomeUIInfo *toolbar;
-  GnomeUIInfo general_toolbar[] = {
-    GNOMEUIINFO_SEPARATOR,
-    GNOMEUIINFO_ITEM_STOCK (N_("New"), N_("New catalog"),
-			    cb_new_file, GNOME_STOCK_PIXMAP_NEW),
-    GNOMEUIINFO_ITEM_STOCK (N_("Open"), N_("Open catalog"),
-			    cb_open_cat, GNOME_STOCK_PIXMAP_OPEN),
-    GNOMEUIINFO_ITEM_STOCK (N_("Save"), N_("Save catalog"),
-			    cb_fast_save, GNOME_STOCK_PIXMAP_SAVE),
-    GNOMEUIINFO_ITEM_STOCK (N_("Save as..."), N_("Save catalog as..."),
-			    cb_save_cat, GNOME_STOCK_PIXMAP_SAVE_AS),
-    GNOMEUIINFO_ITEM_STOCK (N_("Edit categories"), N_("Edit categories"),
-			    cb_edit_categories,
-			    GNOME_STOCK_PIXMAP_PROPERTIES),
-    GNOMEUIINFO_ITEM_STOCK (N_("Preferences"), N_("Preferences"),
-			    cb_run_setup, GNOME_STOCK_PIXMAP_PREFERENCES),
-    GNOMEUIINFO_ITEM_STOCK (N_("Find file"), N_("Find file"),
-			    cb_create_search_dialog,
-			    GNOME_STOCK_PIXMAP_SEARCH),
-    GNOMEUIINFO_ITEM_NONE (N_("Create Report"), N_("Create Report"),
-			   cb_open_report_dialog),
-    GNOMEUIINFO_ITEM_STOCK (N_("Add CD"), N_("Add CD"),
-			    cb_fast_add_disk, GNOME_STOCK_PIXMAP_CDROM),
-    GNOMEUIINFO_ITEM_STOCK (N_("Add dir"), N_("Add dir"),
-			    cb_show_select_dir_win, GNOME_STOCK_PIXMAP_CDROM),
-    GNOMEUIINFO_ITEM_STOCK (N_("Exit"), N_("Quit Gtktalog"),
-			    cb_quit_prog, GNOME_STOCK_PIXMAP_EXIT),
-    GNOMEUIINFO_END
-  };
-
 
   toolbar = (GnomeUIInfo *) g_malloc (14 * sizeof (GnomeUIInfo));
   /* Copy the items from the general toolbar to the toolbar.
@@ -99,6 +101,13 @@ enable_gnome_button_bar (GtkWidget * window, gpointer data)
 
 }
 
+void
+buttons_set_sensitive (gboolean sensitive)
+{
+  gtk_widget_set_sensitive (GTK_WIDGET (toolbar[2].widget), sensitive);
+  gtk_widget_set_sensitive (GTK_WIDGET (toolbar[6].widget), sensitive);
+}
+
 void
 cb_new_file (GtkWidget * w, gpointer data)
 {
@@ -160,6 +169,7 @@ cb_open_recent (GtkWidget * w, gpointer data)
       update_tree (my_config->racine);
 
       gtk_window_set_title (GTK_WINDOW (main_window), filename);
+      menus_set_sensitive (TRUE);
 
     }
 }
@@ -262,6 +272,7 @@ cb_fast_add_disk (GtkWidget * w, gpointer data)
 	  create_tree (my_config->racine);
 	  add_gnode_to_ctree (my_config->racine->tree, my_config->racine);
 	  ctree_window_add (my_config->racine->ctree);
+	  menus_set_sensitive (TRUE);
 	}
       fast_add_disk (my_config->racine);
     }
@@ -278,6 +289,7 @@ cb_show_select_dir_win (GtkWidget * w, gpointer data)
 	  create_tree (my_config->racine);
 	  add_gnode_to_ctree (my_config->racine->tree, my_config->racine);
 	  ctree_window_add (my_config->racine->ctree);
+	  menus_set_sensitive (TRUE);
 	}
       show_select_dir_win (my_config->racine);
     }
