@@ -170,6 +170,9 @@ typedef struct
   PIX *default_disk_pix;
   PIX *default_unreadable_pix;
   PIX *default_vfs_pix;
+  PIX *default_opened_dir_pix;
+  PIX *default_opened_disk_pix;
+  PIX *default_opened_vfs_pix;
   GTree *mime_extensions;
   GTree *mime_vfs_extensions;
 
@@ -219,6 +222,8 @@ typedef struct
   gint mainwindow_w;
   gint mainwindow_h;
   gboolean mainwindow_save_xywh;
+  
+  gint sort_column;
 
 /* What is that? */
   char *fast_name;
