@@ -30,7 +30,9 @@
 #include <fcntl.h>
 #include <unistd.h>
 #include <stdlib.h>
-#include <pthread.h>
+#if defined(USE_PTHREADS)
+#    include <pthread.h>
+#endif
 #include <sys/mtio.h>
 #include <fcntl.h>
 #include <errno.h>
@@ -53,7 +55,9 @@
 
 GtkWidget *name_entry;
 
+#if defined(USE_PTHREADS)
 static pthread_t thread1;
+#endif
 
 int
 fad_create_window (gchar ** fast_name)
@@ -129,14 +133,15 @@ fast_add_disk (FOLDER * racine)
   gint name_window_status;
 
   /* Fetch the content of the drive meanwhile */
-  do_not_forget_to_mount(TRUE);
+  do_not_forget_to_mount (TRUE);
   set_local_disk_name (g_strdup (""));
   set_local_folder_name (escapespaces (my_config->mount_point->str));
 
   set_thread_status_to_running ();
 //  progress_timeout (NULL);
 //  do_not_forget_to_umount (TRUE);
-  init_vfs_scan_status();
+  init_vfs_scan_status ();
+#if defined(USE_PTHREADS)
   if (pthread_create (&thread1, NULL, start_thread_scan, racine) < 0)
     {
       reinit_thread_status ();
@@ -160,4 +165,21 @@ fast_add_disk (FOLDER * racine)
 	}
       my_timeout (racine);
     }
+#else
+/* Initialize the status bar */
+  /* Create window to enter the name */
+  name_window_status = fad_create_window (&(my_config->fast_name));
+
+  if (name_window_status == 1)
+    {
+      set_local_disk_name (my_config->fast_name);
+      set_added_disk (TRUE);
+    }
+  else
+    {
+      set_added_disk (FALSE);
+    }
+  my_timeout (racine);
+  start_thread_scan (racine);
+#endif
 }
