@@ -319,7 +319,7 @@ main_window);
       ERROR_DIALOG (_
 		    ("File seems to have been generated with a version older "
 		     "than 0.1.0 of GTKtalog. Formats are incompatible.\n"
-		     "Try './configure --enable-catalog2' then recompile gtktalog. "
+		     "Try `./configure --enable-catalog2' then recompile gtktalog. "
 		     "Or use the converter!"), main_window);
       return (-1);
 
@@ -371,7 +371,7 @@ main_window);
       ERROR_DIALOG (_
 		    ("File seems to have been generated with a version older "
 		     "than 0.10.1 of GTKtalog. Formats are incompatibles.\n"
-		     "Try './configure --enable-catalog3' then recompile gtktalog "),
+		     "Try `./configure --enable-catalog3' then recompile gtktalog "),
 main_window);
       return (-1);
 #endif
