@@ -46,7 +46,7 @@ struct poptOption command_line[] = {
   {"catalog", 'c', POPT_ARG_STRING || POPT_ARGFLAG_ONEDASH, &popt_filename, P_FILE,
    N_("Catalog file to load."), "filename"},
   {"geometry", 'g', POPT_ARG_STRING || POPT_ARGFLAG_ONEDASH, &popt_geometry, P_GEOMETRY,
-   N_("Geometry. See man X for more info.")},
+   N_("Geometry. See `man X' for more info.")},
   {"title", 't', POPT_ARG_STRING || POPT_ARGFLAG_ONEDASH, &popt_wintitle, P_WINTITLE,
    N_("Title of the window"), "text"},
   {"version", 'v', POPT_ARGFLAG_ONEDASH, NULL, P_VERSION,
@@ -211,7 +211,7 @@ main (int argc, char *argv[])
 		      GTK_SIGNAL_FUNC (save_session), fullname_prog);
   gtk_signal_connect (GTK_OBJECT (client), "die",
 		      GTK_SIGNAL_FUNC (session_die), NULL);
-		      
+
 
   gtk_widget_show (main_window);
   if ((my_config->mainwindow_save_xywh) || (_geometry))
@@ -234,6 +234,7 @@ main (int argc, char *argv[])
       gtk_window_set_title (GTK_WINDOW (main_window),
 			    my_config->racine->catalog_filename->str);
       g_string_free (_filename, TRUE);
+      menus_set_sensitive (TRUE);
     }
 
   gtk_signal_connect (GTK_OBJECT (main_window), "delete_event", cb_quit_prog,
