@@ -102,10 +102,10 @@ _report_cats (GNode * gn, gpointer data)
 	{
 	  fprintf (file, "         %s", fd->name->str);
 	  if ((gb_check_description == TRUE) && (fd->description != 0))
-	    fprintf (file, " : %s",
+	    fprintf (file, ": %s",
 		     folder_get_description_from_file_data (fd));
 	  if ((gb_check_information == TRUE) && (fd->information != 0))
-	    fprintf (file, " : %s", fd->information->str);
+	    fprintf (file, ": %s", fd->information->str);
 	  if ((gb_check_folders)
 	      && ((is_dir (gn) == TRUE) || (is_vfs_any (gn) == TRUE)))
 	    {
@@ -287,13 +287,13 @@ _report_files (GNode * gn, gpointer data)
 		fprintf (file, "  ");
 	      fprintf (file, "%s", fd->name->str);
 	      if ((gb_check_category == TRUE) && (fd->categorie != 0))
-		fprintf (file, " : %s ",
+		fprintf (file, ": %s ",
 			 folder_get_category_from_file_data (fd));
 	      if ((gb_check_description == TRUE) && (fd->description != 0))
-		fprintf (file, " : %s",
+		fprintf (file, ": %s",
 			 folder_get_description_from_file_data (fd));
 	      if ((gb_check_information == TRUE) && (fd->information != 0))
-		fprintf (file, " : %s", fd->information->str);
+		fprintf (file, ": %s", fd->information->str);
 	      if ((gb_check_folders)
 		  && ((is_dir (gn) == TRUE) || (is_vfs_any (gn) == TRUE)))
 		{
@@ -655,7 +655,7 @@ open_report_dialog (FOLDER * racine)
 			     1, 2);
   gtk_widget_show (check_description);
 
-  check_information = gtk_check_button_new_with_label (_("informations"));
+  check_information = gtk_check_button_new_with_label (_("Information"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check_information), FALSE);
   gtk_table_attach_defaults (GTK_TABLE (table), check_information, 1, 2,
 			     2, 3);
