@@ -83,6 +83,7 @@ static GtkWidget *search_list;
 static GtkWidget *checkvfs;
 static GtkWidget *info2desc_button;
 static GtkWidget *info2cat_button;
+static GtkWidget *display_dirs;
 
 /* Search options */
 static gchar *SEARCH_OPTIONS_filename;
@@ -128,12 +129,12 @@ find_node_with_parent (GNode * parent, gchar * name,
   GNode *result;
   FILE_DATA *fd;
 
-  gntmp = g_node_first_sibling (parent);
+  gntmp = g_node_first_child (parent);
   result = NULL;
   while ((result == NULL) && (gntmp))
     {
       fd = get_file_data_from_gnode (gntmp);
-      if (is_dir (gntmp))
+      if (is_dir (gntmp) || is_disk (gntmp))
 	{
 	  if (compare (name, fd->name->str, COMPARE_REGEX, case_sensitive) ==
 	      0)
@@ -177,6 +178,9 @@ gboolean find_files (GNode * gn, gpointer data)
     return (FALSE);
 
   fd = get_file_data_from_gnode (gn);
+  if ((!gtk_toggle_button_get_active
+       (GTK_TOGGLE_BUTTON (display_dirs))) && (is_dir (gn)))
+    return (FALSE);
   if (((fd->a_parent_node_is_vfs != IS_VFS)
        && (fd->a_parent_node_is_vfs != IS_VFS_EXTENDED))
       || SEARCH_OPTIONS_search_in_vfs == TRUE)
@@ -199,7 +203,7 @@ gboolean find_files (GNode * gn, gpointer data)
 
       /* Compare categories */
       tmpstr = get_categorie (racine, fd->categorie);
-      if (strcmp (SEARCH_OPTIONS_category, _(STRING_ALL)))
+      if (strcmp (SEARCH_OPTIONS_category, STRING_ALL))
 	{
 	  if (tmpstr)
 	    {
@@ -217,11 +221,11 @@ gboolean find_files (GNode * gn, gpointer data)
 	   SEARCH_OPTIONS_desc_casesensitive)) return (FALSE);
 
       /* Compare information */
-      if (fd->information)
-	if (compare
-	    (SEARCH_OPTIONS_information, fd->information->str,
-	     SEARCH_OPTIONS_info_regex,
-	     SEARCH_OPTIONS_info_casesensitive)) return (FALSE);
+      tmpstr = folder_get_information_from_file_data (fd);
+      if (compare
+	  (SEARCH_OPTIONS_information, tmpstr,
+	   SEARCH_OPTIONS_info_regex,
+	   SEARCH_OPTIONS_info_casesensitive)) return (FALSE);
 
       /* Compare date */
       if (SEARCH_OPTIONS_size1)
@@ -269,17 +273,21 @@ gboolean find_files (GNode * gn, gpointer data)
 	}
 
       if (gtk_toggle_button_get_active
-	  (GTK_TOGGLE_BUTTON (info2cat_button)) && folder_get_informations (fd->node))
+	  (GTK_TOGGLE_BUTTON (info2cat_button))
+	  && folder_get_informations (fd->node))
 	{
-	    fd->description =
-	      string_to_index (racine->categories, g_strdup(folder_get_informations (fd->node)));
+	  fd->description =
+	    string_to_index (racine->categories,
+			     g_strdup (folder_get_informations (fd->node)));
 	}
 
       if (gtk_toggle_button_get_active
-	  (GTK_TOGGLE_BUTTON (info2desc_button)) && folder_get_informations (fd->node))
+	  (GTK_TOGGLE_BUTTON (info2desc_button))
+	  && folder_get_informations (fd->node))
 	{
-	    fd->description =
-	      description_add (racine->descriptions, g_strdup(folder_get_informations (fd->node)));
+	  fd->description =
+	    description_add (racine->descriptions,
+			     g_strdup (folder_get_informations (fd->node)));
 	}
 
       result[0] = fd->name->str;
@@ -678,7 +686,7 @@ start_extended_search (GtkWidget * w, gpointer data)
   disk = gtk_entry_get_text (GTK_ENTRY (disk_combo_entry));
 
   SEARCH_OPTIONS_search_root = NULL;
-  if (strcmp (disk, _(STRING_ALL)))
+  if (strcmp (disk, STRING_ALL))
     {
       SEARCH_OPTIONS_search_root =
 	find_node_with_parent (racine->tree, disk, FALSE, racine);
@@ -727,7 +735,7 @@ start_simple_search (GtkWidget * w, gpointer data)
 
   SEARCH_OPTIONS_search_in_vfs = FALSE;
 
-  SEARCH_OPTIONS_category = g_strdup (_(STRING_ALL));
+  SEARCH_OPTIONS_category = g_strdup (STRING_ALL);
 
   SEARCH_OPTIONS_description = g_strdup (".*");
   SEARCH_OPTIONS_desc_casesensitive = TRUE;
@@ -1120,7 +1128,7 @@ create_search_dialog (FOLDER * racine)
   disk_combo = gtk_combo_new ();
   gtk_widget_show (disk_combo);
   disk_list = make_disk_list (racine);
-  disk_list = g_list_prepend (disk_list, _(STRING_ALL));
+  disk_list = g_list_prepend (disk_list, STRING_ALL);
   gtk_combo_set_popdown_strings (GTK_COMBO (disk_combo), disk_list);
   g_list_free (disk_list);
   gtk_table_attach (GTK_TABLE (table), disk_combo, 1, 2, 1, 2,
@@ -1281,7 +1289,7 @@ create_search_dialog (FOLDER * racine)
 							 (ext_search_notebook),
 							 1), label);
 
-  frame = gtk_frame_new (_("VFS"));
+  frame = gtk_frame_new (_("VFS and directories"));
   gtk_widget_show (frame);
   gtk_box_pack_start (GTK_BOX (vbox2), frame, TRUE, TRUE, 0);
 
@@ -1293,6 +1301,11 @@ create_search_dialog (FOLDER * racine)
   gtk_widget_show (checkvfs);
   gtk_box_pack_start (GTK_BOX (hbox2), checkvfs, FALSE, FALSE, 0);
 
+  display_dirs = gtk_check_button_new_with_label (_("Display directories"));
+  gtk_widget_show (display_dirs);
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (display_dirs), TRUE);
+  gtk_box_pack_start (GTK_BOX (hbox2), display_dirs, FALSE, FALSE, 0);
+
 /**** Desc & Category ***************/
   table = gtk_table_new (3, 3, FALSE);
   gtk_widget_show (table);
@@ -1316,7 +1329,7 @@ create_search_dialog (FOLDER * racine)
   cat_combo = gtk_combo_new ();
   gtk_widget_show (cat_combo);
   cat_list = make_categories_list (racine);
-  cat_list = g_list_prepend (cat_list, _(STRING_ALL));
+  cat_list = g_list_prepend (cat_list, STRING_ALL);
   gtk_combo_set_popdown_strings (GTK_COMBO (cat_combo), cat_list);
   g_list_free (cat_list);
   gtk_table_attach (GTK_TABLE (table), cat_combo, 1, 2, 0, 1,
