@@ -456,7 +456,7 @@ ei_add_type (GtkWidget * w, gpointer data)
   gtk_container_add (GTK_CONTAINER (vbox2), hbox2);
   gtk_widget_show (hbox2);
 
-  label = gtk_label_new (_("For example 'image/jpeg'"));
+  label = gtk_label_new (_("For example `image/jpeg'"));
   gtk_box_pack_start (GTK_BOX (hbox2), label, TRUE, FALSE, 0);
   gtk_widget_show (label);
 
@@ -844,7 +844,7 @@ add_type (GtkWidget * w, gpointer data)
   gtk_container_add (GTK_CONTAINER (vbox2), hbox2);
   gtk_widget_show (hbox2);
 
-  label = gtk_label_new (_("For example 'image/jpeg'"));
+  label = gtk_label_new (_("For example `image/jpeg'"));
   gtk_box_pack_start (GTK_BOX (hbox2), label, TRUE, FALSE, 0);
   gtk_widget_show (label);
 
@@ -1290,7 +1290,7 @@ vfs_add_type (GtkWidget * w, gpointer data)
   gtk_container_add (GTK_CONTAINER (vbox2), hbox2);
   gtk_widget_show (hbox2);
 
-  label = gtk_label_new (_("For example 'application/x-compressed-tar'"));
+  label = gtk_label_new (_("For example `application/x-compressed-tar'"));
   gtk_box_pack_start (GTK_BOX (hbox2), label, TRUE, FALSE, 0);
   gtk_widget_show (label);
 
@@ -1462,9 +1462,9 @@ vfs_add_type (GtkWidget * w, gpointer data)
 		     "-rw-r--r-- 501/502       14362 2000-08-22 18:33:49 gtktalog/Makefile.in\n"
 		     "drwxr-xr-x 501/502           0 2000-08-22 18:33:49 gtktalog/Docs/\n"
 		     "...\n"
-		     "Separator characters = \" \\t\"\n"
+		     "Separator characters = ` \\t\'\n"
 		     "Date field: 3\n"
-		     "Date format: \"YYYY-MM-DD\"\n"
+		     "Date format: `YYYY-MM-DD'\n"
 		     "Size field: 2\n" "Name field: 5\n"), -1);
   gtk_text_set_editable (GTK_TEXT (label), FALSE);
   gtk_container_add (GTK_CONTAINER (vbox2), label);
