@@ -1,8 +1,12 @@
 #ifndef __THREAD_UTILS_H__
 #define __THREAD_UTILS_H__
 
+#include <config.h>
 #include "config_common.h"
 
+#if !defined(USE_PTHREADS)
+void gui_update (void);
+#endif
 gint get_thread_status ();
 void reinit_thread_status ();
 void set_thread_status_to_running ();
